@@ -40,7 +40,7 @@ from dpys import utils
 RED = 0xD40C00
 BLUE = 0x0000FF
 GREEN = 0x32C12C
-version = "5.0.4"
+version = "5.1.2"
 
 print("We recommend that you read https://jgltechnologies.com/dpys before you use DPYS.")
 
@@ -437,7 +437,7 @@ class warnings:
             if punishment not in ["temp_ban", "temp_mute", "mute", "ban", "kick"]:
                 raise Exception("Invalid punishment.")
             self.punishment = punishment
-            if punishment.startswith("temp"):
+            if not punishment.startswith("temp"):
                 self.duration = None
             else:
                 self.duration = duration
@@ -480,14 +480,15 @@ class warnings:
                 async with db.execute("SELECT reason FROM warnings WHERE guild = ? and member_id = ?",
                                       (guildid, member)) as cursor:
                     embed = discord.Embed(
-                        color=BLUE, title=f"{user.name}#{user.discriminator}'s Warnings")
+                        color=BLUE, title=f"{user.name}#{user.discriminator}'s 5 Most Recent Warnings")
                     number = 0
                     async for entry in cursor:
+                        if number < 5:
+                            embed.add_field(
+                                name=f"#{number} warning",
+                                value=f"Reason: {entry[0]}",
+                                inline=False)
                         number += 1
-                        embed.add_field(
-                            name=f"#{number} warning",
-                            value=f"Reason: {entry[0]}",
-                            inline=False)
                     if number > 0:
                         embed.set_footer(text=f"Total Warnings | {number}")
                         await inter.response.send_message(embed=embed, ephemeral=True)
@@ -582,17 +583,6 @@ class warnings:
                         member TEXT,
                         time DATETIME
                         )""")
-            await db.execute("""CREATE TABLE IF NOT EXISTS mute_roles_info(
-                        guild TEXT PRIMARY KEY,
-                        role_add TEXT,
-                        role_remove TEXT
-                        )""")
-            try:
-                await db.execute("INSERT INTO mute_roles_info (guild,role_add,role_remove) VALUES (?,?,?)",
-                                 (guild, str(add_role), str(remove_role)))
-            except:
-                await db.execute("UPDATE mute_roles_info SET role_add = ?, role_remove = ? WHERE guild = ?",
-                                 (str(add_role), str(remove_role), guild))
             await db.execute("""CREATE TABLE IF NOT EXISTS tempban(
                         guild TEXT,
                         member TEXT,
@@ -671,7 +661,8 @@ class warnings:
                     await mute_on_join.mute_add(inter.guild, member, dir)
 
     @staticmethod
-    async def temp_mute_loop(dir: str, bot: commands.Bot) -> None:
+    async def temp_mute_loop(dir: str, bot: commands.Bot, add_role_func: typing.Awaitable,
+                             remove_role_func: typing.Optional[typing.Awaitable] = None) -> None:
         await asyncio.get_event_loop().run_in_executor(None, os.chdir, dir)
         async with aiosqlite.connect("warnings.db") as db:
             try:
@@ -691,22 +682,21 @@ class warnings:
                                 await db.commit()
                                 continue
                             time = datetime.datetime.fromisoformat(time_str)
-                            async with db.execute("SELECT role_add FROM mute_roles_info WHERE guild = ?",
-                                                  (str(guild.id),)) as role_add_cursor:
-                                role_add = await role_add_cursor.fetchone()
-                            async with db.execute("SELECT role_remove FROM mute_roles_info WHERE guild = ?",
-                                                  (str(guild.id),)) as role_remove_cursor:
-                                role_remove = await role_remove_cursor.fetchone()
+                            role_add = await add_role_func(int(guild_id))
+                            if remove_role_func is None:
+                                role_remove = None
+                            else:
+                                role_remove = await remove_role_func(int(guild_id))
                             if datetime.datetime.now() >= time:
-                                if role_remove != "None" and role_remove != "None":
+                                if role_add is not None:
                                     try:
                                         await member.add_roles(guild.get_role(int(role_remove)))
                                     except:
                                         pass
-                                try:
-                                    await member.remove_roles(guild.get_role(int(role_add)))
-                                except:
-                                    pass
+                                    try:
+                                        await member.remove_roles(guild.get_role(int(role_add)))
+                                    except:
+                                        pass
                                 await db.execute("DELETE FROM tempmute WHERE guild = ? and member = ? and time = ?",
                                                  (str(guild.id), str(member.id), time_str))
                                 await db.commit()
@@ -961,7 +951,7 @@ class rr:
         await asyncio.get_event_loop().run_in_executor(None, os.chdir, dir)
         guild = str(inter.guild.id)
         async with aiosqlite.connect("rr.db") as db:
-            embed = discord.Embed(title="Reaction Roles", color=BLUE)
+            embed = discord.Embed(title="5 Most Recent Reaction Roles", color=BLUE)
             try:
                 async with db.execute("SELECT msg_id FROM rr WHERE guild = ? GROUP BY msg_id", (guild,)) as cursor:
                     number = 0
@@ -989,25 +979,26 @@ class rr:
                                 msg_limit += f"Channel: {channel} \nMessage ID: {msg_id}\n"
                                 msg += f"Channel: {channel} \nMessage ID: {msg_id}\n"
                                 number += 1
-                            if len(msg) > 1010:
-                                embed.add_field(
-                                    name=f"Reaction Role #{number}", inline=False, value=msg_limit)
-                                limit = True
-                            else:
-                                limit = False
-                                embed.add_field(
-                                    name=f"Reaction Role #{number}", inline=False, value=msg)
+                            if number < 6:
+                                if len(msg) > 1010:
+                                    embed.add_field(
+                                        name=f"Reaction Role #{number}", inline=False, value=msg_limit)
+                                    limit = True
+                                else:
+                                    limit = False
+                                    embed.add_field(
+                                        name=f"Reaction Role #{number}", inline=False, value=msg)
                         except:
                             continue
                 if number > 0:
                     if limit:
                         embed.set_footer(
                             text=f"Total Reaction Roles | {number}")
+                        msg = "One of your reaction roles went over the Discord limit. It will still work perfectly but only essential data will be displayed in this command to save space."
+                        await inter.channel.send(msg, delete_after=10)
                     else:
                         embed.set_footer(
                             text=f"Total Reaction Roles | {number}")
-                        msg = "One of your reaction roles went over the Discord limit. It will still work perfectly but only essential data will be displayed in this command to save space."
-                        await inter.channel.send(msg, delete_after=10)
                     await inter.response.send_message(embed=embed)
                 else:
                     msg = "There are no reaction roles in this server."
